BoardArrow class

An arrow for the last move done on board.

Constructors

BoardArrow({required String from, required String to, required Color color})
Constructor. from : from square (e.g 'd2'). to : to square (e.g 'd4'). color: color of the arrow from flutter material package (e.g Colors.green).

Properties

color → Color
Color: color of the arrow from flutter material package (e.g Colors.green).
final
from → String
From square (e.g 'd2').
final
hashCode → int
Hash code.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
to → String
To square (e.g 'd4').
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
Equality operator.
override