Piece class

Constructors

Piece(BoardColor color, PieceType type)
const

Properties

color → BoardColor
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → PieceType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

blackBishop ↔ Piece
getter/setter pair
blackKing ↔ Piece
getter/setter pair
blackKnight ↔ Piece
getter/setter pair
blackPawn ↔ Piece
getter/setter pair
blackQueen ↔ Piece
getter/setter pair
blackRook ↔ Piece
getter/setter pair
whiteBishop ↔ Piece
getter/setter pair
whiteKing ↔ Piece
getter/setter pair
whiteKnight ↔ Piece
getter/setter pair
whitePawn ↔ Piece
getter/setter pair
whiteQueen ↔ Piece
getter/setter pair
whiteRook ↔ Piece
getter/setter pair