ChessBoardColors class

Colors used by the chess board.

Constructors

ChessBoardColors()
Constructor.

Properties

circularProgressBarColor ↔ Color
The color of the circular progress bar.
getter/setter pair
coordinatesColor ↔ Color
The color of the coordinates.
getter/setter pair
coordinatesZoneColor ↔ Color
The color of the coordinates zone.
getter/setter pair
darkSquaresColor ↔ Color
The color of the dark squares.
getter/setter pair
dndIndicatorColor ↔ Color?
Optional color for the drag and drop indicator's cells.
getter/setter pair
endSquareColor ↔ Color
The color of the end square for drag and drop
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastMoveArrowColor ↔ Color
The color of last move arrow.
getter/setter pair
lightSquaresColor ↔ Color
The color of the light squares.
getter/setter pair
possibleMovesColor ↔ Color
The color of the possible move indicators (dots).
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
startSquareColor ↔ Color
The color of the start square for drag and drop, or for click then click move.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited