onBoardResized property

void Function(double newCellSize)? onBoardResized
final

Callback for whenever board is resized. Parameter is the new cell common side size (double). Please notice that you should avoid generating a new build of the board from this callback, otherwise you'll end up with an infinite rendering.

Implementation

final void Function(double newCellSize)? onBoardResized;