NavigationControlsStyle class

Styling options for navigation controls

Constructors

Properties

decoration → BoxDecoration?
Background decoration for the controls container
final
disabledIconColor → Color
Color for disabled icons
final
enabledIconColor → Color
Color for enabled icons
final
hashCode → int
The hash code for this object.
no setterinherited
iconSize → double
Size of the navigation icons
final
padding → EdgeInsets
Padding around the controls
final
positionIndicatorColor → Color
Background color for position indicator
final
positionTextStyle → TextStyle
Text style for position indicator
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited